@@ -5,7 +5,7 @@
 ## This program is free software. It may be copied and/or redistributed under
 ## the same terms as Perl itself.
 ##==============================================================================
-## $Id: Util.pm,v 0.4 2004/06/06 01:01:33 kevin Exp $
+## $Id: Util.pm,v 0.6 2004/07/25 04:44:44 kevin Exp $
 ##==============================================================================
 require 5.006;
 
@@ -13,7 +13,7 @@ package ## don't want this indexed yet
 	Lexical::Util;
 use strict;
 use warnings;
-our $VERSION = '0.2';
+our ($VERSION) = q$Revision: 0.6 $ =~ /Revision:\s+(\S+)/ or $VERSION = '0.0';
 use Carp;
 
 BEGIN {
@@ -27,7 +27,7 @@ require XSLoader;
 XSLoader::load('Lexical::Util', $VERSION);
 
 use base qw(Exporter);
-our @EXPORT_OK = qw(frame_to_cvref lexalias);
+our @EXPORT_OK = qw(frame_to_cvref lexalias ref_to_lexical);
 
 =head1 NAME
 
@@ -35,10 +35,11 @@ Lexical::Util - utilities for lexical item manipulation
 
 =head1 SYNOPSIS
 
-	use Lexical::Util qw(frame_to_cvref lexalias);
+	use Lexical::Util qw(frame_to_cvref lexalias ref_to_lexical);
 
 	$cvref = frame_to_cvref($level);
 	lexalias($cvref, '$name', \$variable);
+	$ref = ref_to_lexical($cvref, '$name');
 
 =head1 DESCRIPTION
 
@@ -47,9 +48,10 @@ dealing with the lexical variables of routines other than their own. They are
 taken from various sources, including L<PadWalker|PadWalker>,
 L<Perl6::Binding|Perl6::Binding>, and L<Lexical::Alias|Lexical::Alias>. This
 module is used in version 0.7 and greater of Perl6::Binding, as well as in the
-L<fields::aliased|fields::aliased> package, to prevent duplication of code.
+L<Object::Variables|Object::Variables> and L<Sub::Declaration|Sub::Declaration>
+packages, to prevent duplication of code.
 
-This package should I<not> be used by end users.
+This package should I<not> be needed or used by end users.
 
 Note: this module uses the L<CvPADLIST|perlintern/CvPADLIST> and CvDEPTH macros,
 which are listed in L<perlintern|perlintern> and not part of the perl API. They
@@ -77,6 +79,14 @@ Creates a lexical alias for a variable called I<$name> pointing to the variable
 I<$value>. I<$cvref> is a code reference returned by L<"frame_to_cvref">. If
 I<$cvref> is B<undef>, this routine dies.
 
+=item ref_to_lexical
+
+C<< I<$ref> = ref_to_lexical(I<$cvref>, 'I<$name>'); >>
+
+Returns a reference to the named lexical variable in the specified stack frame.
+I<$cvref> is a code reference returned by L<"frame_to_cvref">. If I<$cvref> is
+B<undef> or the specified name isn't found, this routine dies.
+
 =back
 
 =head1 KNOWN ISSUES
@@ -110,6 +120,12 @@ Kevin Michael Vail <F<kevin>@F<vaildc>.F<net>>
 
 ##==============================================================================
 ## $Log: Util.pm,v $
+## Revision 0.6  2004/07/25 04:44:44  kevin
+## Update POD; change the way the version number is computed.
+##
+## Revision 0.5  2004/07/10 01:14:32  kevin
+## Add ref_to_lexical function.
+##
 ## Revision 0.4  2004/06/06 01:01:33  kevin
 ## Bump version number.
 ##
